| Title: | IMPACT outputs R package for IMPACT version 3.x |
|---|---|
| Description: | Common output routines for extracting results from the IMPACT framework (versions 3.x). |
| Authors: | Abhijeet Mishra [aut, cre] |
| Maintainer: | Abhijeet Mishra <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 4.17.0 |
| Built: | 2026-06-01 09:48:28 UTC |
| Source: | https://github.com/IFPRI/reportIMPACT |
animals
animals(gdx, ...)animals(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO animals
Abhijeet Mishra
## Not run: x <- animals(gdx)## Not run: x <- animals(gdx)
biofuelFeedstock
biofuelFeedstock(gdx, ...)biofuelFeedstock(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO biofuelFeedstock
Abhijeet Mishra
## Not run: x <- biofuelFeedstock(gdx)## Not run: x <- biofuelFeedstock(gdx)
Calculate relative change for IMPACT indicators
calcRelative( df, base_year = 2005, cols = c("description", "model", "indicator", "region", "unit"), type = "same_unit" )calcRelative( df, base_year = 2005, cols = c("description", "model", "indicator", "region", "unit"), type = "same_unit" )
df |
Full IMAPCT result for an indicator |
base_year |
base year on which the relative indicator is calculated |
cols |
columns which are used for relative index calculation |
type |
If relative index is calculate in same unit ('same_unit') or as an index on base year ('index') |
Recalculate dataframe with relative calculation
## Not run: x <- calcRelative(df=reportPopulation(gdx))## Not run: x <- calcRelative(df=reportPopulation(gdx))
clean_description
clean_description(df)clean_description(df)
df |
dataframe with description column |
GLO population
Abhijeet Mishra
## Not run: x <- clean_description(df)## Not run: x <- clean_description(df)
Clean unit
clean_unit(df)clean_unit(df)
df |
dataframe with description column |
Converted units if needed
Abhijeet Mishra
## Not run: x <- clean_unit(df)## Not run: x <- clean_unit(df)
Consumer Prices
consumerPrices(gdx, ...)consumerPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO consumerPrices
Abhijeet Mishra
## Not run: x <- consumerPrices(gdx)## Not run: x <- consumerPrices(gdx)
cropArea
cropArea(gdx, ...)cropArea(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO cropArea
Abhijeet Mishra
## Not run: x <- cropArea(gdx)## Not run: x <- cropArea(gdx)
cropAreaAgg
cropAreaAgg(gdx, ...)cropAreaAgg(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO cropAreaAgg
Abhijeet Mishra
## Not run: x <- cropAreaAgg(gdx)## Not run: x <- cropAreaAgg(gdx)
Demand
demand(gdx, ...)demand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO Demand
Abhijeet Mishra
## Not run: x <- Demand(gdx)## Not run: x <- Demand(gdx)
Domestic Export Prices
DomesticExportPrices(gdx, ...)DomesticExportPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO DomesticExportPrices
Abhijeet Mishra
## Not run: x <- DomesticExportPrices(gdx)## Not run: x <- DomesticExportPrices(gdx)
Domestic Import Prices
DomesticImportPrices(gdx, ...)DomesticImportPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO DomesticImportPrices
Abhijeet Mishra
## Not run: x <- DomesticImportPrices(gdx)## Not run: x <- DomesticImportPrices(gdx)
export
export(gdx, ...)export(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO export
Abhijeet Mishra
## Not run: x <- export(gdx)## Not run: x <- export(gdx)
FoodAvailability
foodAvailability(gdx, ...)foodAvailability(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO FoodAvailability
Abhijeet Mishra
## Not run: x <- foodAvailability(gdx)## Not run: x <- foodAvailability(gdx)
GDP
GDP(gdx, ...)GDP(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO GDP
Abhijeet Mishra
## Not run: x <- GDP(gdx)## Not run: x <- GDP(gdx)
getReport
getReport( gdx, additional_indicators = FALSE, prep_flag = NULL, export = TRUE, base_year = NULL, sp_mapping = "Standard-IMPACT_dis1", relative_calc = FALSE )getReport( gdx, additional_indicators = FALSE, prep_flag = NULL, export = TRUE, base_year = NULL, sp_mapping = "Standard-IMPACT_dis1", relative_calc = FALSE )
gdx |
final GDX from an IMPACT run |
additional_indicators |
If non-core indicators should be read. |
prep_flag |
Who processed data. Defaults to user name from the computer where this script is run. |
export |
if RDS file should be written. Defaults to TRUE |
base_year |
Base year on which relative index can be calculated. Default 2005. |
sp_mapping |
Which mapping to use. See mapping file in DOORMAT package. |
relative_calc |
If relative calculations should be done |
Full data output
Abhijeet Mishra
## Not run: x <- getReport(gdx)## Not run: x <- getReport(gdx)
householdDemand
householdDemand(gdx, ...)householdDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO householdDemand
Abhijeet Mishra
## Not run: x <- householdDemand(gdx)## Not run: x <- householdDemand(gdx)
householdIncome
householdIncome(gdx, ...)householdIncome(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO householdIncome
Abhijeet Mishra
## Not run: x <- householdIncome(gdx)## Not run: x <- householdIncome(gdx)
householdPopulation
householdPopulation(gdx, ...)householdPopulation(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO householdPopulation
Abhijeet Mishra
## Not run: x <- householdPopulation(gdx)## Not run: x <- householdPopulation(gdx)
hungerRisk
hungerRisk(gdx, ...)hungerRisk(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO hungerRisk
Abhijeet Mishra
## Not run: x <- hungerRisk(gdx)## Not run: x <- hungerRisk(gdx)
import
import(gdx, ...)import(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO import
Abhijeet Mishra
## Not run: x <- import(gdx)## Not run: x <- import(gdx)
Intermediate Demand
intermediateDemand(gdx, ...)intermediateDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO other Demand
Abhijeet Mishra
## Not run: x <- intermediateDemand(gdx)## Not run: x <- intermediateDemand(gdx)
Level based summing
levelSum( df, dim_name = NULL, spatial = "region", temporal = "yrs", na.rm = TRUE, bind = TRUE )levelSum( df, dim_name = NULL, spatial = "region", temporal = "yrs", na.rm = TRUE, bind = TRUE )
df |
A dataframe which comes out of aggregateIMPACT function call |
dim_name |
The column to be summed over. Usually "long_name" |
spatial |
Which column contains spatial info. Defaults to "region" |
temporal |
Which column contains temporal info. Defaults to "yrs" |
na.rm |
If NAs should be ignored during sum. Defaults to TRUE |
bind |
If new aggregation should be binded to the original dataframe passed on to "df" argument |
Aggregated dataframe
## Not run: x <- levelSum(df)## Not run: x <- levelSum(df)
lsfDemand
lsfDemand(gdx, ...)lsfDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO lsfDemand
Abhijeet Mishra
## Not run: x <- lsfDemand(gdx)## Not run: x <- lsfDemand(gdx)
Malnourished
malnourished(gdx, ...)malnourished(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO malnourished
Abhijeet Mishra
## Not run: x <- malnourished(gdx)## Not run: x <- malnourished(gdx)
Name Cleaner
name_cleaner(df, fix_only_na = FALSE)name_cleaner(df, fix_only_na = FALSE)
df |
placeholder dataframe for cleanup |
fix_only_na |
if only NA as character in cols should be fixed |
cleaned dataframe with right names
## Not run: x <- name_cleaner(df)## Not run: x <- name_cleaner(df)
Net Prices
NetPrices(gdx, ...)NetPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO NetPrices
Abhijeet Mishra
## Not run: x <- NetPrices(gdx)## Not run: x <- NetPrices(gdx)
netTrade
netTrade(gdx, ...)netTrade(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO netExport
Abhijeet Mishra
## Not run: x <- netExport(gdx)## Not run: x <- netExport(gdx)
Other Demand
otherDemand(gdx, ...)otherDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO other Demand
Abhijeet Mishra
## Not run: x <- otherDemand(gdx)## Not run: x <- otherDemand(gdx)
percapGDP
percapGDP(gdx, ...)percapGDP(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO percapGDP
Abhijeet Mishra
## Not run: x <- percapGDP(gdx)## Not run: x <- percapGDP(gdx)
KCal per Capita
PerCapKCal(gdx, ...)PerCapKCal(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
Per capita KCal availability
Abhijeet Mishra
## Not run: x <- PerCapKCal(gdx)## Not run: x <- PerCapKCal(gdx)
KCal per Capita per Commodity
PerCapKCalCommodity(gdx, ...)PerCapKCalCommodity(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
Per capita KCal availability
Abhijeet Mishra
## Not run: x <- PerCapKCalCommodity(gdx)## Not run: x <- PerCapKCalCommodity(gdx)
Population
population(gdx, ...)population(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- population(gdx)## Not run: x <- population(gdx)
Producer Prices
producerPrices(gdx, ...)producerPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO producerPrices
Abhijeet Mishra
## Not run: x <- producerPrices(gdx)## Not run: x <- producerPrices(gdx)
Production
production(gdx, ...)production(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO Production
Abhijeet Mishra
## Not run: x <- Production(gdx)## Not run: x <- Production(gdx)
reportAnimals
reportAnimals(gdx, ...)reportAnimals(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO Animals
Abhijeet Mishra
## Not run: x <- reportAnimals(gdx)## Not run: x <- reportAnimals(gdx)
reportBiofuelFeedstock
reportBiofuelFeedstock(gdx, ...)reportBiofuelFeedstock(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO BiofuelFeedstock
Abhijeet Mishra
## Not run: x <- reportBiofuelFeedstock(gdx)## Not run: x <- reportBiofuelFeedstock(gdx)
reportConsumerPrices
reportConsumerPrices(gdx, ...)reportConsumerPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO CropArea
Abhijeet Mishra
## Not run: x <- reportConsumerPrices(gdx)## Not run: x <- reportConsumerPrices(gdx)
reportCropArea
reportCropArea(gdx, ...)reportCropArea(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO CropArea
Abhijeet Mishra
## Not run: x <- reportCropArea(gdx)## Not run: x <- reportCropArea(gdx)
reportDemand
reportDemand(gdx, ...)reportDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportDemand(gdx)## Not run: x <- reportDemand(gdx)
reportDomesticExportPrices
reportDomesticExportPrices(gdx, ...)reportDomesticExportPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO CropArea
Abhijeet Mishra
## Not run: x <- reportDomesticExportPrices(gdx)## Not run: x <- reportDomesticExportPrices(gdx)
reportDomesticImportPrices
reportDomesticImportPrices(gdx, ...)reportDomesticImportPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO CropArea
Abhijeet Mishra
## Not run: x <- reportDomesticImportPrices(gdx)## Not run: x <- reportDomesticImportPrices(gdx)
reportExport
reportExport(gdx, ...)reportExport(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO export
Abhijeet Mishra
## Not run: x <- reportexport(gdx)## Not run: x <- reportexport(gdx)
reportFoodAvailability
reportFoodAvailability(gdx, ...)reportFoodAvailability(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO FoodAvailability
Abhijeet Mishra
## Not run: x <- reportFoodAvailability(gdx)## Not run: x <- reportFoodAvailability(gdx)
reportGDP
reportGDP(gdx, ...)reportGDP(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportGDP(gdx)## Not run: x <- reportGDP(gdx)
reportHouseholdDemand
reportHouseholdDemand(gdx, ...)reportHouseholdDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportHouseholdDemand(gdx)## Not run: x <- reportHouseholdDemand(gdx)
reportHouseholdIncome
reportHouseholdIncome(gdx, ...)reportHouseholdIncome(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportHouseholdIncome(gdx)## Not run: x <- reportHouseholdIncome(gdx)
reportHouseholdPopulation
reportHouseholdPopulation(gdx, ...)reportHouseholdPopulation(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportHouseholdPopulation(gdx)## Not run: x <- reportHouseholdPopulation(gdx)
reportHungerRisk
reportHungerRisk(gdx, ...)reportHungerRisk(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportHungerRisk(gdx)## Not run: x <- reportHungerRisk(gdx)
reportImport
reportImport(gdx, ...)reportImport(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO export
Abhijeet Mishra
## Not run: x <- reportImport(gdx)## Not run: x <- reportImport(gdx)
reportIntermediateDemand
reportIntermediateDemand(gdx, ...)reportIntermediateDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportIntermediateDemand(gdx)## Not run: x <- reportIntermediateDemand(gdx)
reportLSFDemand
reportLSFDemand(gdx, ...)reportLSFDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportLSFDemand(gdx)## Not run: x <- reportLSFDemand(gdx)
reportMalnourished
reportMalnourished(gdx, ...)reportMalnourished(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO Malnourished
Abhijeet Mishra
## Not run: x <- reportMalnourished(gdx)## Not run: x <- reportMalnourished(gdx)
reportNetPrices
reportNetPrices(gdx, ...)reportNetPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
Solution Net Prices
Abhijeet Mishra
## Not run: x <- reportNetPrices(gdx)## Not run: x <- reportNetPrices(gdx)
reportNetTrade
reportNetTrade(gdx, ...)reportNetTrade(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO NetExport
Abhijeet Mishra
## Not run: x <- reportNetExport(gdx)## Not run: x <- reportNetExport(gdx)
reportOtherDemand
reportOtherDemand(gdx, ...)reportOtherDemand(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportOtherDemand(gdx)## Not run: x <- reportOtherDemand(gdx)
reportPerCapGDP
reportPerCapGDP(gdx, ...)reportPerCapGDP(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportPerCapGDP(gdx)## Not run: x <- reportPerCapGDP(gdx)
reportPerCapKCal
reportPerCapKCal(gdx, ...)reportPerCapKCal(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO FoodAvailability
Abhijeet Mishra
## Not run: x <- reportPerCapKCal(gdx)## Not run: x <- reportPerCapKCal(gdx)
reportPerCapKCalCommodity
reportPerCapKCalCommodity(gdx, ...)reportPerCapKCalCommodity(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO FoodAvailability
Abhijeet Mishra
## Not run: x <- reportPerCapKCalCommodity(gdx)## Not run: x <- reportPerCapKCalCommodity(gdx)
reportPopulation
reportPopulation(gdx, ...)reportPopulation(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportPopulation(gdx)## Not run: x <- reportPopulation(gdx)
reportProducerPrices
reportProducerPrices(gdx, ...)reportProducerPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO CropArea
Abhijeet Mishra
## Not run: x <- reportproducerPrices(gdx)## Not run: x <- reportproducerPrices(gdx)
reportProduction
reportProduction(gdx, ...)reportProduction(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportProduction(gdx)## Not run: x <- reportProduction(gdx)
reportSingleWorldPrices
reportSingleWorldPrices(gdx, ...)reportSingleWorldPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO CropArea
Abhijeet Mishra
## Not run: x <- reportSingleWorldPrices(gdx)## Not run: x <- reportSingleWorldPrices(gdx)
reportSupply
reportSupply(gdx, ...)reportSupply(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO population
Abhijeet Mishra
## Not run: x <- reportSupply(gdx)## Not run: x <- reportSupply(gdx)
reportWeightedWorldPrices
reportWeightedWorldPrices(gdx, ...)reportWeightedWorldPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO CropArea
Abhijeet Mishra
## Not run: x <- reportWeightedWorldPrices(gdx)## Not run: x <- reportWeightedWorldPrices(gdx)
reportYields
reportYields(gdx, ...)reportYields(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO Yield
Abhijeet Mishra
## Not run: x <- reportYield(gdx)## Not run: x <- reportYield(gdx)
Single World Prices
singleWorldPrices(gdx, ...)singleWorldPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO singleWorldPrices
Abhijeet Mishra
## Not run: x <- singleWorldPrices(gdx)## Not run: x <- singleWorldPrices(gdx)
Supply
supply(gdx, ...)supply(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO supply
Abhijeet Mishra
## Not run: x <- supply(gdx)## Not run: x <- supply(gdx)
World Prices
weightedWorldPrices(gdx, ...)weightedWorldPrices(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO weightedWorldPrices
Abhijeet Mishra
## Not run: x <- weightedWorldPrices(gdx)## Not run: x <- weightedWorldPrices(gdx)
Yields
yields(gdx, ...)yields(gdx, ...)
gdx |
final GDX from an IMPACT run |
... |
Arguments to aggregateIMPACT call. See ?aggregateIMPACT |
GLO Yields
Abhijeet Mishra
## Not run: x <- Yields(gdx)## Not run: x <- Yields(gdx)